@@ -4,14 +4,16 @@ use strict;
 BEGIN {
 	require 5.004;
 	require Exporter;
-	$YAML::Tiny::VERSION   = '1.28_01';
+	$YAML::Tiny::VERSION   = '1.34_01';
 	$YAML::Tiny::errstr    = '';
 	@YAML::Tiny::ISA       = qw{ Exporter  };
+	@YAML::Tiny::EXPORT = qw{
+		Load Dump
+	};
 	@YAML::Tiny::EXPORT_OK = qw{
-		Load     Dump
 		LoadFile DumpFile
 		freeze   thaw
-		};
+	};
 }
 
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f\"\n]';
@@ -50,9 +52,13 @@ sub read {
 	# Slurp in the file
 	local $/ = undef;
 	local *CFG;
-	open( CFG, $file ) or return $class->_error( "Failed to open file '$file': $!" );
+	unless ( open(CFG, $file) ) {
+		return $class->_error( "Failed to open file '$file': $!" );
+	}
 	my $contents = <CFG>;
-	close( CFG ) or return $class->_error( "Failed to close file '$file': $!" );
+	unless ( close(CFG) ) {
+		return $class->_error( "Failed to close file '$file': $!" );
+	}
 
 	$class->read_string( $contents );
 }
@@ -138,20 +144,11 @@ sub _read_scalar {
 		$str =~ s/\\([never\\fartz]|x([0-9a-fA-F]{2}))/(length($1)>1)?pack("H2",$2):$UNESCAPES{$1}/gex;
 		return $str;
 	}
-	if ( $string =~ /^['"]/ ) {
-		# A quote with folding... we don't support that
-		die "YAML::Tiny does not support multi-line quoted scalars";
-	}
 
-	# Null hash and array
-	if ( $string eq '{}' ) {
-		# Null hash
-		return {};		
-	}
-	if ( $string eq '[]' ) {
-		# Null array
-		return [];
-	}
+	# Special cases
+	die "Unsupported YAML feature" if $string =~ /^['"!&]/;
+	return {} if $string eq '{}';
+	return [] if $string eq '[]';
 
 	# Regular unquoted string
 	return $string unless $string =~ /^[>|]/;
@@ -268,6 +265,7 @@ sub _read_hash {
 
 		# Get the key
 		unless ( $lines->[0] =~ s/^\s*([^\'\" ][^\n]*?)\s*:(\s+|$)// ) {
+			die "Unsupported YAML feature" if $lines->[0] =~ /^\s*[?'"]/;
 			die "Bad or unsupported hash line";
 		}
 		my $key = $1;
@@ -336,7 +334,7 @@ sub write_string {
 
 		# A scalar document
 		} elsif ( ! ref $cursor ) {
-			$lines[-1] .= ' ' . $self->_write_scalar( $cursor );
+			$lines[-1] .= ' ' . $self->_write_scalar( $cursor, $indent );
 
 		# A list at the root
 		} elsif ( ref $cursor eq 'ARRAY' ) {
@@ -389,7 +387,7 @@ sub _write_array {
 		my $line = ('  ' x $indent) . '-';
 		my $type = ref $el;
 		if ( ! $type ) {
-			$line .= ' ' . $self->_write_scalar( $el );
+			$line .= ' ' . $self->_write_scalar( $el, $indent + 1 );
 			push @lines, $line;
 
 		} elsif ( $type eq 'ARRAY' ) {
@@ -429,7 +427,7 @@ sub _write_hash {
 		my $line = ('  ' x $indent) . "$name:";
 		my $type = ref $el;
 		if ( ! $type ) {
-			$line .= ' ' . $self->_write_scalar( $el );
+			$line .= ' ' . $self->_write_scalar( $el, $indent + 1 );
 			push @lines, $line;
 
 		} elsif ( $type eq 'ARRAY' ) {
